@@ -105,9 +105,32 @@ class AirtableInterface:
         """
         field_val = cls.get_airtable_value(
             record, field_name, default, supress_warnings)
-        dt_local = parse(field_val).astimezone()
 
-        return dt_local
+        if field_val:
+            dt_local = parse(field_val).astimezone()
+            return dt_local
+
+        return None
+
+    @classmethod
+    def get_airtable_date(
+        cls, record, field_name, default=None, supress_warnings=False):
+        """Retrieves a date value from an Airtable record field.
+
+        Args:
+            record: The Airtable record.
+            field_name: The name of the record's field.
+            default: The default value of the field.
+            supress_warnings: Flag to turn off warnings.
+        """
+        field_val = cls.get_airtable_value(
+            record, field_name, default, supress_warnings)
+
+        if field_val:
+            dte_local = parse(field_val).date()
+            return dte_local
+
+        return None
 
     @classmethod
     def create_record(cls, table, fields):
@@ -159,3 +182,17 @@ class AirtableInterface:
         record = table.update(record_id, fields, typecast=True)
 
         return record
+
+    @classmethod
+    def delete_record(cls, table, record_id):
+        """Deletes the specified record.
+
+        Args:
+            table: The Airtable Table object.
+            record_id: The Airtable record identifier.
+        """
+        record = None
+
+        record = table.delete(record_id)
+
+        return record
